@@ -14,3 +14,12 @@ requiet <- function(package) {
 requiet("tinytest")
 requiet("tinysnapshot")
 
+
+
+clean_html <- function(x) {
+  x <- gsub("tinytable_\\w+\\b", "tinytable", x)
+  x <- gsub("styleCell_\\w+\\b", "tinytable", x)
+  x <- gsub("insertSpanRow\\w+\\b", "tinytable", x)
+  x <- gsub("styleHeaderCell_\\w+\\b", "tinytable", x)
+  x
+}
